(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5403],{59916:(e,n,r)=>{"use strict";r.r(n),r.d(n,{default:()=>s});var t=r(93476),o=r.n(t)()((function(e){return e[1]}));o.push([e.id,"/*\n\n    Name:       Bespin\n    Author:     Mozilla / Jan T. Sott\n\n    CodeMirror template by Jan T. Sott (https://github.com/idleberg/base16-codemirror)\n    Original Base16 color scheme by Chris Kempson (https://github.com/chriskempson/base16)\n\n*/\n\n.cm-s-bespin.CodeMirror {background: #28211c; color: #9d9b97;}\n.cm-s-bespin div.CodeMirror-selected {background: #36312e !important;}\n.cm-s-bespin .CodeMirror-gutters {background: #28211c; border-right: 0px;}\n.cm-s-bespin .CodeMirror-linenumber {color: #666666;}\n.cm-s-bespin .CodeMirror-cursor {border-left: 1px solid #797977 !important;}\n\n.cm-s-bespin span.cm-comment {color: #937121;}\n.cm-s-bespin span.cm-atom {color: #9b859d;}\n.cm-s-bespin span.cm-number {color: #9b859d;}\n\n.cm-s-bespin span.cm-property, .cm-s-bespin span.cm-attribute {color: #54be0d;}\n.cm-s-bespin span.cm-keyword {color: #cf6a4c;}\n.cm-s-bespin span.cm-string {color: #f9ee98;}\n\n.cm-s-bespin span.cm-variable {color: #54be0d;}\n.cm-s-bespin span.cm-variable-2 {color: #5ea6ea;}\n.cm-s-bespin span.cm-def {color: #cf7d34;}\n.cm-s-bespin span.cm-error {background: #cf6a4c; color: #797977;}\n.cm-s-bespin span.cm-bracket {color: #9d9b97;}\n.cm-s-bespin span.cm-tag {color: #cf6a4c;}\n.cm-s-bespin span.cm-link {color: #9b859d;}\n\n.cm-s-bespin .CodeMirror-matchingbracket { text-decoration: underline; color: white !important;}\n.cm-s-bespin .CodeMirror-activeline-background { background: #404040; }\n",""]);const s=o},93476:e=>{"use strict";e.exports=function(e){var n=[];return n.toString=function(){return this.map((function(n){var r=e(n);return n[2]?"@media ".concat(n[2]," {").concat(r,"}"):r})).join("")},n.i=function(e,r,t){"string"==typeof e&&(e=[[null,e,""]]);var o={};if(t)for(var s=0;s<this.length;s++){var i=this[s][0];null!=i&&(o[i]=!0)}for(var a=0;a<e.length;a++){var c=[].concat(e[a]);t&&o[c[0]]||(r&&(c[2]?c[2]="".concat(r," and ").concat(c[2]):c[2]=r),n.push(c))}},n}},95403:(e,n,r)=>{var t=r(59916);"string"==typeof(t=t.__esModule?t.default:t)&&(t=[[e.id,t,""]]);r(1892)(t,{insert:"head",singleton:!1}),t.locals&&(e.exports=t.locals)},1892:(e,n,r)=>{"use strict";var t,o={},s=function(){var e={};return function(n){if(void 0===e[n]){var r=document.querySelector(n);if(window.HTMLIFrameElement&&r instanceof window.HTMLIFrameElement)try{r=r.contentDocument.head}catch(e){r=null}e[n]=r}return e[n]}}();function i(e,n){for(var r=[],t={},o=0;o<e.length;o++){var s=e[o],i=n.base?s[0]+n.base:s[0],a={css:s[1],media:s[2],sourceMap:s[3]};t[i]?t[i].parts.push(a):r.push(t[i]={id:i,parts:[a]})}return r}function a(e,n){for(var r=0;r<e.length;r++){var t=e[r],s=o[t.id],i=0;if(s){for(s.refs++;i<s.parts.length;i++)s.parts[i](t.parts[i]);for(;i<t.parts.length;i++)s.parts.push(f(t.parts[i],n))}else{for(var a=[];i<t.parts.length;i++)a.push(f(t.parts[i],n));o[t.id]={id:t.id,refs:1,parts:a}}}}function c(e){var n=document.createElement("style");if(void 0===e.attributes.nonce){var t=r.nc;t&&(e.attributes.nonce=t)}if(Object.keys(e.attributes).forEach((function(r){n.setAttribute(r,e.attributes[r])})),"function"==typeof e.insert)e.insert(n);else{var o=s(e.insert||"head");if(!o)throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");o.appendChild(n)}return n}var l,p=(l=[],function(e,n){return l[e]=n,l.filter(Boolean).join("\n")});function u(e,n,r,t){var o=r?"":t.css;if(e.styleSheet)e.styleSheet.cssText=p(n,o);else{var s=document.createTextNode(o),i=e.childNodes;i[n]&&e.removeChild(i[n]),i.length?e.insertBefore(s,i[n]):e.appendChild(s)}}function d(e,n,r){var t=r.css,o=r.media,s=r.sourceMap;if(o&&e.setAttribute("media",o),s&&btoa&&(t+="\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(s))))," */")),e.styleSheet)e.styleSheet.cssText=t;else{for(;e.firstChild;)e.removeChild(e.firstChild);e.appendChild(document.createTextNode(t))}}var m=null,b=0;function f(e,n){var r,t,o;if(n.singleton){var s=b++;r=m||(m=c(n)),t=u.bind(null,r,s,!1),o=u.bind(null,r,s,!0)}else r=c(n),t=d.bind(null,r,n),o=function(){!function(e){if(null===e.parentNode)return!1;e.parentNode.removeChild(e)}(r)};return t(e),function(n){if(n){if(n.css===e.css&&n.media===e.media&&n.sourceMap===e.sourceMap)return;t(e=n)}else o()}}e.exports=function(e,n){(n=n||{}).attributes="object"==typeof n.attributes?n.attributes:{},n.singleton||"boolean"==typeof n.singleton||(n.singleton=(void 0===t&&(t=Boolean(window&&document&&document.all&&!window.atob)),t));var r=i(e,n);return a(r,n),function(e){for(var t=[],s=0;s<r.length;s++){var c=r[s],l=o[c.id];l&&(l.refs--,t.push(l))}e&&a(i(e,n),n);for(var p=0;p<t.length;p++){var u=t[p];if(0===u.refs){for(var d=0;d<u.parts.length;d++)u.parts[d]();delete o[u.id]}}}}}}]);