(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6345,4645],{94645:(e,t,o)=>{"use strict";o.r(t),o.d(t,{default:()=>c});var n=o(65579),s=o(82959),a=o(49839),r=o(24318);const c=[{id:"@retrolab/console-extension:opener",requires:[n.IRouter],autoStart:!0,activate:(e,t)=>{const{commands:o}=e,n=new RegExp("/consoles/(.*)"),s="router:console";o.addCommand(s,{execute:e=>{const t=e.path.match(n);if(!t)return;const[,s]=t;if(!s)return;const a=decodeURIComponent(s);o.execute("console:create",{path:a})}}),t.register({command:s,pattern:n})}},{id:"@retrolab/console-extension:redirect",requires:[s.IConsoleTracker],autoStart:!0,activate:(e,t)=>{const o=a.PageConfig.getBaseUrl();t.widgetAdded.connect((async(t,n)=>{const{sessionContext:s}=n;await s.ready,(0,r.find)(e.shell.widgets("main"),(e=>e.id===n.id))||(window.open(`${o}retro/consoles/${s.path}`,"_blank"),n.dispose())}))}}]}}]);