(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5905],{11452:(e,n,t)=>{"use strict";t.r(n),t.d(n,{default:()=>s});var r=t(93476),c=t.n(r)()((function(e){return e[1]}));c.push([e.id,".cm-s-eclipse span.cm-meta { color: #FF1717; }\n.cm-s-eclipse span.cm-keyword { line-height: 1em; font-weight: bold; color: #7F0055; }\n.cm-s-eclipse span.cm-atom { color: #219; }\n.cm-s-eclipse span.cm-number { color: #164; }\n.cm-s-eclipse span.cm-def { color: #00f; }\n.cm-s-eclipse span.cm-variable { color: black; }\n.cm-s-eclipse span.cm-variable-2 { color: #0000C0; }\n.cm-s-eclipse span.cm-variable-3, .cm-s-eclipse span.cm-type { color: #0000C0; }\n.cm-s-eclipse span.cm-property { color: black; }\n.cm-s-eclipse span.cm-operator { color: black; }\n.cm-s-eclipse span.cm-comment { color: #3F7F5F; }\n.cm-s-eclipse span.cm-string { color: #2A00FF; }\n.cm-s-eclipse span.cm-string-2 { color: #f50; }\n.cm-s-eclipse span.cm-qualifier { color: #555; }\n.cm-s-eclipse span.cm-builtin { color: #30a; }\n.cm-s-eclipse span.cm-bracket { color: #cc7; }\n.cm-s-eclipse span.cm-tag { color: #170; }\n.cm-s-eclipse span.cm-attribute { color: #00c; }\n.cm-s-eclipse span.cm-link { color: #219; }\n.cm-s-eclipse span.cm-error { color: #f00; }\n\n.cm-s-eclipse .CodeMirror-activeline-background { background: #e8f2ff; }\n.cm-s-eclipse .CodeMirror-matchingbracket { outline:1px solid grey; color:black !important; }\n",""]);const s=c},93476:e=>{"use strict";e.exports=function(e){var n=[];return n.toString=function(){return this.map((function(n){var t=e(n);return n[2]?"@media ".concat(n[2]," {").concat(t,"}"):t})).join("")},n.i=function(e,t,r){"string"==typeof e&&(e=[[null,e,""]]);var c={};if(r)for(var s=0;s<this.length;s++){var o=this[s][0];null!=o&&(c[o]=!0)}for(var a=0;a<e.length;a++){var i=[].concat(e[a]);r&&c[i[0]]||(t&&(i[2]?i[2]="".concat(t," and ").concat(i[2]):i[2]=t),n.push(i))}},n}},65905:(e,n,t)=>{var r=t(11452);"string"==typeof(r=r.__esModule?r.default:r)&&(r=[[e.id,r,""]]);t(1892)(r,{insert:"head",singleton:!1}),r.locals&&(e.exports=r.locals)},1892:(e,n,t)=>{"use strict";var r,c={},s=function(){var e={};return function(n){if(void 0===e[n]){var t=document.querySelector(n);if(window.HTMLIFrameElement&&t instanceof window.HTMLIFrameElement)try{t=t.contentDocument.head}catch(e){t=null}e[n]=t}return e[n]}}();function o(e,n){for(var t=[],r={},c=0;c<e.length;c++){var s=e[c],o=n.base?s[0]+n.base:s[0],a={css:s[1],media:s[2],sourceMap:s[3]};r[o]?r[o].parts.push(a):t.push(r[o]={id:o,parts:[a]})}return t}function a(e,n){for(var t=0;t<e.length;t++){var r=e[t],s=c[r.id],o=0;if(s){for(s.refs++;o<s.parts.length;o++)s.parts[o](r.parts[o]);for(;o<r.parts.length;o++)s.parts.push(h(r.parts[o],n))}else{for(var a=[];o<r.parts.length;o++)a.push(h(r.parts[o],n));c[r.id]={id:r.id,refs:1,parts:a}}}}function i(e){var n=document.createElement("style");if(void 0===e.attributes.nonce){var r=t.nc;r&&(e.attributes.nonce=r)}if(Object.keys(e.attributes).forEach((function(t){n.setAttribute(t,e.attributes[t])})),"function"==typeof e.insert)e.insert(n);else{var c=s(e.insert||"head");if(!c)throw new Error("Couldn't find a style target. This probably means that the value for the 'insert' parameter is invalid.");c.appendChild(n)}return n}var l,p=(l=[],function(e,n){return l[e]=n,l.filter(Boolean).join("\n")});function u(e,n,t,r){var c=t?"":r.css;if(e.styleSheet)e.styleSheet.cssText=p(n,c);else{var s=document.createTextNode(c),o=e.childNodes;o[n]&&e.removeChild(o[n]),o.length?e.insertBefore(s,o[n]):e.appendChild(s)}}function f(e,n,t){var r=t.css,c=t.media,s=t.sourceMap;if(c&&e.setAttribute("media",c),s&&btoa&&(r+="\n/*# sourceMappingURL=data:application/json;base64,".concat(btoa(unescape(encodeURIComponent(JSON.stringify(s))))," */")),e.styleSheet)e.styleSheet.cssText=r;else{for(;e.firstChild;)e.removeChild(e.firstChild);e.appendChild(document.createTextNode(r))}}var m=null,d=0;function h(e,n){var t,r,c;if(n.singleton){var s=d++;t=m||(m=i(n)),r=u.bind(null,t,s,!1),c=u.bind(null,t,s,!0)}else t=i(n),r=f.bind(null,t,n),c=function(){!function(e){if(null===e.parentNode)return!1;e.parentNode.removeChild(e)}(t)};return r(e),function(n){if(n){if(n.css===e.css&&n.media===e.media&&n.sourceMap===e.sourceMap)return;r(e=n)}else c()}}e.exports=function(e,n){(n=n||{}).attributes="object"==typeof n.attributes?n.attributes:{},n.singleton||"boolean"==typeof n.singleton||(n.singleton=(void 0===r&&(r=Boolean(window&&document&&document.all&&!window.atob)),r));var t=o(e,n);return a(t,n),function(e){for(var r=[],s=0;s<t.length;s++){var i=t[s],l=c[i.id];l&&(l.refs--,r.push(l))}e&&a(o(e,n),n);for(var p=0;p<r.length;p++){var u=r[p];if(0===u.refs){for(var f=0;f<u.parts.length;f++)u.parts[f]();delete c[u.id]}}}}}}]);