(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6720],{66541:(e,t,o)=>{"use strict";o.r(t),o.d(t,{default:()=>c});var n=o(96667),a=o(61865),r=o(40384),s=o(807),i=o(48423),l=o(36735);const c=[{id:"@retrolab/tree-extension:buttons",requires:[a.IFileBrowserFactory],autoStart:!0,activate:(e,t)=>{const{commands:o}=e,a=t.defaultBrowser,r="tree:new-notebook";o.addCommand(r,{label:"New Notebook",icon:i.notebookIcon,execute:()=>o.execute("notebook:create-new")});const s=new n.CommandToolbarButton({commands:o,id:r}),l=new n.CommandToolbarButton({commands:o,id:"filebrowser:create-new-file"});a.toolbar.insertItem(0,"new-notebook",s),a.toolbar.insertItem(1,"new-file",l)}},{id:"@retrolab/tree-extension:new-console",requires:[a.IFileBrowserFactory],autoStart:!0,activate:(e,t)=>{const{commands:o}=e,a=t.defaultBrowser,r="tree:new-console";o.addCommand(r,{label:"New Console",icon:i.consoleIcon,execute:()=>o.execute("console:create")});const s=new n.CommandToolbarButton({commands:o,id:r});a.toolbar.insertItem(2,"new-console",s)}},{id:"@retrolab/tree-extension:new-terminal",requires:[a.IFileBrowserFactory],autoStart:!0,activate:(e,t)=>{const{commands:o}=e,a=t.defaultBrowser,r="tree:new-terminal";o.addCommand(r,{label:"New Terminal",icon:i.terminalIcon,execute:()=>o.execute("terminal:create-new")});const s=new n.CommandToolbarButton({commands:o,id:r});a.toolbar.insertItem(3,"new-terminal",s)}},{id:"@jupyterlab-classic/tree-extension:widget",requires:[a.IFileBrowserFactory,s.ITranslator],optional:[r.IRunningSessionManagers],autoStart:!0,activate:(e,t,o,n)=>{const a=new l.TabPanel({tabPlacement:"top",tabsMovable:!0});a.addClass("jp-TreePanel");const{defaultBrowser:s}=t;if(s.title.label="Files",a.addWidget(s),a.tabBar.addTab(s.title),n){const e=new r.RunningSessions(n,o);e.id="jp-running-sessions",e.title.label="Running",e.title.icon=i.runningIcon,a.addWidget(e),a.tabBar.addTab(e.title)}e.shell.add(a,"main",{rank:100})}}]}}]);