(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[5060,9434],{79434:(e,t,r)=>{"use strict";r.r(t),r.d(t,{default:()=>s});var o=r(49839),i=r(35044),n=r(96700);const s=[{id:"@jupyterlab/docprovider-extension:plugin",provides:i.IDocumentProviderFactory,activate:e=>{const t=n.ServerConnection.makeSettings(),r=o.URLExt.join(t.wsUrl,"api/yjs"),s="true"==o.PageConfig.getOption("collaborative");return e=>s?new i.WebSocketProviderWithLocks(Object.assign(Object.assign({},e),{url:r})):new i.ProviderMock}}]}}]);